==> CGAL-6.0.3-doc_html.zip: doc_html/BGL/group__PkgBGLEulerOperations.js <==
var group__PkgBGLEulerOperations =
[
    [ "CGAL::Euler::add_center_vertex", "group__PkgBGLEulerOperations.html#gaddf9d21ebb0ad54d9502e9ea507aa5db", null ],
    [ "CGAL::Euler::add_edge", "group__PkgBGLEulerOperations.html#ga312d98be9ea19607d677f873a01d6a82", null ],
    [ "CGAL::Euler::add_face", "group__PkgBGLEulerOperations.html#gaa386d0cdef3b5d6ef43d6b503392dbcd", null ],
    [ "CGAL::Euler::add_face_to_border", "group__PkgBGLEulerOperations.html#ga2012dc1b47d60c6cbe69061ceb07c0ce", null ],
    [ "CGAL::Euler::add_vertex_and_face_to_border", "group__PkgBGLEulerOperations.html#ga5fe1ebdf2f52204339e70258b918ed76", null ],
    [ "CGAL::Euler::can_add_face", "group__PkgBGLEulerOperations.html#ga7dc63595108097b6e28b04fe962135f0", null ],
    [ "CGAL::Euler::collapse_edge", "group__PkgBGLEulerOperations.html#ga2f6543e9758cea9380a4896f04217aa4", null ],
    [ "CGAL::Euler::collapse_edge", "group__PkgBGLEulerOperations.html#gaaf9abf3f088f97463ede1ccfaa93b9d3", null ],
    [ "CGAL::Euler::does_satisfy_link_condition", "group__PkgBGLEulerOperations.html#ga8af4fd79178c66fef7091614c0bc4a01", null ],
    [ "CGAL::Euler::fill_hole", "group__PkgBGLEulerOperations.html#ga12e0a6376e2755b48356b186e1344fdb", null ],
    [ "CGAL::Euler::flip_edge", "group__PkgBGLEulerOperations.html#ga174af506cebf3def60b56a3501843864", null ],
    [ "CGAL::Euler::join_face", "group__PkgBGLEulerOperations.html#gaf98d4e129e7540001c030cbda75570e9", null ],
    [ "CGAL::Euler::join_loop", "group__PkgBGLEulerOperations.html#gaced3c3f58b5ac310e04e26b0b72c4aa0", null ],
    [ "CGAL::Euler::join_vertex", "group__PkgBGLEulerOperations.html#ga1760f0f8e7bf35de6f396b6b86a0b9bb", null ],
    [ "CGAL::Euler::make_hole", "group__PkgBGLEulerOperations.html#gaa305bfc634d2aa7bca376d0550d8363e", null ],
    [ "CGAL::Euler::remove_center_vertex", "group__PkgBGLEulerOperations.html#gafa44d3b18f6492b95bb64c137d2ec18d", null ],
    [ "CGAL::Euler::remove_face", "group__PkgBGLEulerOperations.html#gacfae7ff8e782da55b941e4487e86c738", null ],
    [ "CGAL::Euler::split_edge", "group__PkgBGLEulerOperations.html#ga01dc93c57ad0079240dd9554de46a176", null ],
    [ "CGAL::Euler::split_face", "group__PkgBGLEulerOperations.html#gadc29dd4ad63e653e4eedf02220bb48da", null ],
    [ "CGAL::Euler::split_loop", "group__PkgBGLEulerOperations.html#gafbcf6ce6bf656f5e927ff9ea3c22a105", null ],
    [ "CGAL::Euler::split_vertex", "group__PkgBGLEulerOperations.html#gab86d0b0c959a8103ae58dc5ba23fb40d", null ]
];

==> CGAL-6.1.1-doc_html.zip: doc_html/BGL/group__PkgBGLEulerOperations.js <==
var group__PkgBGLEulerOperations =
[
    [ "CGAL::Euler::add_center_vertex", "group__PkgBGLEulerOperations.html#gaddf9d21ebb0ad54d9502e9ea507aa5db", null ],
    [ "CGAL::Euler::add_edge", "group__PkgBGLEulerOperations.html#ga312d98be9ea19607d677f873a01d6a82", null ],
    [ "CGAL::Euler::add_face", "group__PkgBGLEulerOperations.html#gaa386d0cdef3b5d6ef43d6b503392dbcd", null ],
    [ "CGAL::Euler::add_face_to_border", "group__PkgBGLEulerOperations.html#ga2012dc1b47d60c6cbe69061ceb07c0ce", null ],
    [ "CGAL::Euler::add_vertex_and_face_to_border", "group__PkgBGLEulerOperations.html#ga5fe1ebdf2f52204339e70258b918ed76", null ],
    [ "CGAL::Euler::can_add_face", "group__PkgBGLEulerOperations.html#ga7dc63595108097b6e28b04fe962135f0", null ],
    [ "CGAL::Euler::collapse_edge", "group__PkgBGLEulerOperations.html#ga2f6543e9758cea9380a4896f04217aa4", null ],
    [ "CGAL::Euler::collapse_edge", "group__PkgBGLEulerOperations.html#gaaf9abf3f088f97463ede1ccfaa93b9d3", null ],
    [ "CGAL::Euler::does_satisfy_link_condition", "group__PkgBGLEulerOperations.html#ga8af4fd79178c66fef7091614c0bc4a01", null ],
    [ "CGAL::Euler::fill_hole", "group__PkgBGLEulerOperations.html#ga12e0a6376e2755b48356b186e1344fdb", null ],
    [ "CGAL::Euler::flip_edge", "group__PkgBGLEulerOperations.html#ga174af506cebf3def60b56a3501843864", null ],
    [ "CGAL::Euler::join_face", "group__PkgBGLEulerOperations.html#gaf98d4e129e7540001c030cbda75570e9", null ],
    [ "CGAL::Euler::join_loop", "group__PkgBGLEulerOperations.html#gaced3c3f58b5ac310e04e26b0b72c4aa0", null ],
    [ "CGAL::Euler::join_vertex", "group__PkgBGLEulerOperations.html#ga1760f0f8e7bf35de6f396b6b86a0b9bb", null ],
    [ "CGAL::Euler::make_hole", "group__PkgBGLEulerOperations.html#gaa305bfc634d2aa7bca376d0550d8363e", null ],
    [ "CGAL::Euler::remove_center_vertex", "group__PkgBGLEulerOperations.html#gafa44d3b18f6492b95bb64c137d2ec18d", null ],
    [ "CGAL::Euler::remove_degree_2_vertex", "group__PkgBGLEulerOperations.html#gab3455663b7db4624529e54ae3ce2387c", null ],
    [ "CGAL::Euler::remove_face", "group__PkgBGLEulerOperations.html#gacfae7ff8e782da55b941e4487e86c738", null ],
    [ "CGAL::Euler::split_edge", "group__PkgBGLEulerOperations.html#ga01dc93c57ad0079240dd9554de46a176", null ],
    [ "CGAL::Euler::split_face", "group__PkgBGLEulerOperations.html#gadc29dd4ad63e653e4eedf02220bb48da", null ],
    [ "CGAL::Euler::split_loop", "group__PkgBGLEulerOperations.html#gafbcf6ce6bf656f5e927ff9ea3c22a105", null ],
    [ "CGAL::Euler::split_vertex", "group__PkgBGLEulerOperations.html#gab86d0b0c959a8103ae58dc5ba23fb40d", null ]
];
